Package: midfieldr
Title: Tools and Methods for Working with MIDFIELD Data in 'R'
Version: 1.0.3
Authors@R: c(
    person("Richard", "Layton", , "graphdoctor@gmail.com", role = c("cre", "aut", "cph")),
    person("Russell", "Long", , "ralong@purdue.edu", role = c("aut", "cph", "dtm")),
    person("Matthew", "Ohland", , "ohland@purdue.edu", role = c("aut", "cph")),
    person("Marisa", "Orr", role = c("aut", "cph")),
    person("Susan", "Lord", , "slord@sandiego.edu", role = c("aut", "cph"))
  )
Maintainer: Richard Layton <graphdoctor@gmail.com>
Description: Provides tools and demonstrates methods for working with
    individual undergraduate student-level records (registrar's data) in
    'R'. Tools include filters for program codes, data sufficiency, and
    timely completion. Methods include gathering blocs of records,
    computing quantitative metrics such as graduation rate, and creating
    charts to visualize comparisons. 'midfieldr' interacts with practice
    data provided in 'midfielddata', an R data package available at
    <https://midfieldr.github.io/midfielddata/>.  'midfieldr' also
    interacts with the full MIDFIELD database for users who have access.
    As of the transfer of MIDFIELD to the American Society for Engineering
    Education in 2023, the development, expansion, and study of
    MIDFIELD has been supported by the National Science Foundation grants
    0337629, 0646441, 0729596, 0734062, 0835914, 0935157, 0935058,
    0969474, 1025171, 1129383, 1232740, 1329283, 1361058, 1545667,
    2142087, 2141903, and 2152441.
License: MIT + file LICENSE
URL: https://midfieldr.github.io/midfieldr/
BugReports: https://github.com/MIDFIELDR/midfieldr/issues
Depends: R (>= 3.5.0)
Imports: checkmate, data.table (>= 1.9.8), stats, wrapr
Suggests: knitr, rmarkdown, tinytest
VignetteBuilder: knitr, rmarkdown
Config/roxygen2/version: 8.0.0
Encoding: UTF-8
Language: en-US
LazyData: TRUE
LazyDataCompression: bzip2
NeedsCompilation: no
Packaged: 2026-05-10 16:20:22 UTC; layto
Author: Richard Layton [cre, aut, cph],
  Russell Long [aut, cph, dtm],
  Matthew Ohland [aut, cph],
  Marisa Orr [aut, cph],
  Susan Lord [aut, cph]
Repository: CRAN
Date/Publication: 2026-05-10 16:30:02 UTC
Built: R 4.5.2; ; 2026-05-10 17:08:23 UTC; unix
