# Generated by roxygen2: do not edit by hand

export(add_completion_status)
export(add_data_sufficiency)
export(add_timely_term)
export(check_equiv_frames)
export(filter_cip)
export(order_multiway)
export(prep_fye_mice)
export(select_required)
importFrom(checkmate,assert_data_frame)
importFrom(checkmate,assert_int)
importFrom(checkmate,assert_names)
importFrom(checkmate,assert_subset)
importFrom(checkmate,qassert)
importFrom(data.table,"%chin%")
importFrom(data.table,"%like%")
importFrom(data.table,":=")
importFrom(data.table,.N)
importFrom(data.table,.SD)
importFrom(data.table,as.data.table)
importFrom(data.table,copy)
importFrom(data.table,fcase)
importFrom(data.table,fifelse)
importFrom(data.table,setDF)
importFrom(data.table,setDT)
importFrom(data.table,setcolorder)
importFrom(data.table,setkey)
importFrom(data.table,setkeyv)
importFrom(data.table,setnames)
importFrom(data.table,setorder)
importFrom(data.table,setorderv)
importFrom(data.table,shift)
importFrom(stats,na.omit)
importFrom(stats,reorder)
importFrom(wrapr,"%?%")
importFrom(wrapr,check_equiv_frames)
importFrom(wrapr,let)
importFrom(wrapr,stop_if_dot_args)
