---
title: "midfieldr"
output: rmarkdown::html_vignette
vignette: >
  %\VignetteIndexEntry{midfieldr}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

Please see the midfieldr website for full documentation:

  * <https://midfieldr.github.io/midfieldr/>
  
The website also includes articles describing typical applications in detail: 

  * [Index of articles](https://midfieldr.github.io/midfieldr/articles/index.html)
  



