```{r child-preparing-data-setup}
#| include: true

# Packages
library(midfieldr)    # check_equiv_frames()
library(midfielddata) # datasets
library(data.table)   # data manipulation system
library(dplyr)        # data manipulation system
library(tidyr)        # drop_na()

# Initialize data frames 
data(student, term)
student_df  <- data.frame(student)
student_dt  <- copy(student)
student_tbl <- tibble(student)
term_df  <- data.frame(term)
term_dt  <- copy(term)
term_tbl <- tibble(term)
```
