[MIDFIELD](https://midfield.online/). &nbsp; A database of anonymized student-level records for approximately 2.4M undergraduates at 21 US institutions from 1987-2022. In 2023, control and management of the database was transferred to the American Society for Engineering Education (ASEE). For further information, contact ASEE.  

[midfielddata](https://midfieldr.github.io/midfielddata/). &nbsp; An R data package that supplies anonymized student-level records for 98,000 undergraduates at three US institutions from 1988-2018. A sample of the MIDFIELD database, midfielddata provides practice data for the tools and methods in the midfieldr package.
