
```{r}
#| echo: false

# Restore the user options (saved in common-setup.Rmd)
options(backup_options)

# Restore user random number seed if any
if (!is.null(oldseed)) {.Random.seed <- oldseed}

# to change the CSS file
# per https://github.com/rstudio/rmarkdown/issues/732
knitr::opts_chunk$set(echo = FALSE)
```


<!-- blockquote { -->
<!--     padding:     10px 20px; -->
<!--     margin:      0 0 20px; -->
<!--     border-left: 0px -->
<!-- } -->
<!-- caption { -->
<!--     color:       #525252; -->
<!--     text-align:  left; -->
<!--     font-weight: normal; -->
<!--     font-size:   medium; -->
<!--     line-height: 1.5; -->
<!-- } -->
