As of the transfer of MIDFIELD to the American Society for Engineering 
Education (ASEE) in 2023, the development, expansion, and study of 
MIDFIELD has been supported by the National Science Foundation grants 
0337629, 0646441, 0729596, 0734062, 0835914, 0935157, 0935058, 
0969474, 1025171, 1129383, 1232740, 1329283, 1361058, 1545667, 
2142087, 2141903, and 2152441.
