student-level data

: Data at the "student-level" refers to information about individual students including, for example, demographics, programs, academic standing, courses, grades, and degrees. Also called Student Unit Records (SURs). 

: MIDFIELD student-level data are provided in four data tables (`student`, `course`, `term`, and `degree`) that were compiled by institutions and anonymized and curated by the MIDFIELD data steward.   
